@@ -1,5 +1,5 @@
 package Net::Twitter::Role::API::RESTv1_1;
-$Net::Twitter::Role::API::RESTv1_1::VERSION = '4.01007';
+$Net::Twitter::Role::API::RESTv1_1::VERSION = '4.01008';
 use Moose::Role;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use Net::Twitter::API;
@@ -2052,6 +2052,45 @@ Returns an array of numeric user ids the authenticating user has muted.
     returns  => 'ArrayRef[Int]',
 );
 
+twitter_api_method muting => (
+    description => <<'',
+Returns an array of user objects that the authenticating user is muting.
+
+    path     => 'mutes/users/list',
+    aliases  => [qw/mutes_list/],
+    method   => 'GET',
+    params   => [qw/cursor include_entities skip_status/],
+    required => [qw//],
+    returns  => 'ArrayRef[BasicUser]',
+);
+
+twitter_api_method create_mute => (
+    description => <<'',
+Mutes the user specified in the C<user_id> or C<screen_name> parameter as the
+authenticating user.  Returns the muted user when successful.  You can find
+out more about muting in the Twitter Support Knowledge Base.
+
+    path     => 'mutes/users/create',
+    method   => 'POST',
+    params   => [qw/user_id screen_name/],
+    booleans => [qw//],
+    required => [qw/id/],
+    returns  => 'BasicUser',
+);
+
+twitter_api_method destroy_mute => (
+    description => <<'',
+Un-mutes the user specified in the C<user_id> or C<screen_name> parameter as
+the authenticating user.  Returns the un-muted user when successful.
+
+    path     => 'mutes/users/destroy',
+    method   => 'POST',
+    params   => [qw/user_id screen_name/],
+    booleans => [qw//],
+    required => [qw/id/],
+    returns  => 'BasicUser',
+);
+
 twitter_api_method lookup_statuses => (
     description => <<'',
 Returns a hash reference of tweets from an arbitrary set of ids.
@@ -2104,7 +2143,7 @@ Net::Twitter::Role::API::RESTv1_1 - A definition of the Twitter REST API v1.1 as
 
 =head1 VERSION
 
-version 4.01007
+version 4.01008
 
 =head1 SYNOPSIS
 
